#
# spec file for package python-tzdata
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-tzdata
Version:        2025.1
Release:        1.1
Summary:        Provider of IANA time zone data
License:        Apache-2.0
URL:            https://github.com/python/tzdata
Source:         https://files.pythonhosted.org/packages/source/t/tzdata/tzdata-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-subtests}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools >= 40.8.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Provider of IANA time zone data

%prep
%autosetup -p1 -n tzdata-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc NEWS.md README.rst
%license licenses/LICENSE_APACHE
%{python_sitelib}/tzdata
%{python_sitelib}/tzdata-%{version}.dist-info

%changelog
* Sun Jan 26 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 2025.1
  * Paraguay adopts permanent -03 starting spring 2024
* Wed Oct  2 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2024.2
  * Improve historical data for Mexico, Mongolia, and Portugal.
  * System V names are now obsolescent.
  * The main data form now uses %%z.
  * The code now conforms to RFC 8536 for early timestamps.
  * Support POSIX.1-2024, which removes asctime_r and ctime_r.
  * Assume POSIX.2-1992 or later for shell scripts.
  * SUPPORT_C89 now defaults to 1.
* Wed Mar 27 2024 Christian Keil <keil@dfn-cert.de>
- Switch to Python 3.11 build.
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.1:
  * Upstream version 2024a
  * Kazakhstan unifies on UTC+5 beginning 2024-03-01. Palestine
    springs forward a week later after Ramadan.
    zic no longer pretends to support indefinite-past DST.
  * localtime no longer mishandles Ciudad Juárez in 2422.
  * Kazakhstan unifies on UTC+5.  This affects Asia/Almaty and
    Asia/Qostanay which together represent the eastern portion
    of the country that will transition from UTC+6 on
    2024-03-01 at 00:00 to join the western portion.
  * Palestine springs forward a week later than previously
    predicted in 2024 and 2025.
  * Asia/Ho_Chi_Minh's 1955-07-01 transition occurred at 01:00
    not 00:00.
  * From 1947 through 1949, Toronto's transitions occurred at
    02:00 not 00:00.
  * In 1911 Miquelon adopted standard time on June 15, not May
    15.
  * The strftime man page documents which struct tm members
    affect which conversion specs, and that tzset is called.
* Wed Feb  7 2024 Steve Kowalik <steven.kowalik@suse.com>
- Initial release of 2023.4.
